import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.Locale;


class Tile {
	final char ch;
	
	Tile(char ch) {
		this.ch = ch;
	}
	
	boolean isBlue() {
		return ch == '#';
	}
	
	boolean isWhite() {
		return ch == '.'; 
	}
	
	boolean isRed() {
		return ch == '/' || ch == '\\'; 
	}
}

public class FreeCellStatistics {

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		
		String inFileName = args[0];
		BufferedReader in = new BufferedReader(new FileReader(inFileName));
		BufferedWriter out = new BufferedWriter(new FileWriter(inFileName + ".out"));
		int testCases = Integer.parseInt(in.readLine());

		for (int caseNo = 1; caseNo <= testCases; ++caseNo) {
			final String[] caseStr = in.readLine().split(" ");
			final long speedBoosters = Long.parseLong(caseStr[0]);
			long buildTime = Long.parseLong(caseStr[1]);
			final long N = Long.parseLong(caseStr[2]);
			final int C = Integer.parseInt(caseStr[3]);
			final long[] dist = new long[C];
			
			for (int i = 0; i < C; ++i) {
				dist[i] = Long.parseLong(caseStr[4 + i]);
			}
			
			LinkedList<Long> travelTimes = new LinkedList<Long>();
			
			for (int i = 0; i < N; ++i) {
				int index = i % C;
				travelTimes.add(2 * dist[index]);
			}
			
			long time = 0;
			
			while (buildTime > 0 && !travelTimes.isEmpty()) {
				long travelTime = travelTimes.pop();
				
				if (travelTime <= buildTime) {
					buildTime -= travelTime;
					time += travelTime;
				} else {
					travelTime -= buildTime;
					time += buildTime;
					buildTime = 0;
					travelTimes.push(travelTime);
				}
			}
			
			Collections.sort(travelTimes);
			
			for (int i = 0; i < speedBoosters && !travelTimes.isEmpty(); ++i) {
				time += travelTimes.pollLast() / 2;
			}
			
			for (Long i : travelTimes) {
				time += i;
			}
			
			StringBuilder result = new StringBuilder();
			result.append(time);
			
			final String resultStr = "Case #" + caseNo + ": " + result.toString() + "\n";
			out.write(resultStr);
			System.out.print(resultStr);
			out.flush();
		}
	}
}
