package war;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.StringTokenizer;

public class WarSolver {
	static float[][][] readInputs(String path) throws IOException {
		InputStream ips = new FileInputStream(path);
		InputStreamReader ipsr = new InputStreamReader(ips);
		BufferedReader br = new BufferedReader(ipsr);
		String ligne;

		ligne = br.readLine();
		int casesCount = Integer.parseInt(ligne);
		float[][][] arrayModels = new float[casesCount][][];

		for (int c = 0; c < casesCount; c++) {
			ligne = br.readLine();
			int nbBlock = Integer.parseInt(ligne);
			arrayModels[c] = new float[2][];
			arrayModels[c][0] = new float[nbBlock];
			arrayModels[c][1] = new float[nbBlock];

			ligne = br.readLine();
			StringTokenizer tokenizer = new StringTokenizer(ligne);
			for (int i = 0; i < nbBlock; i++) {
				arrayModels[c][0][i] = Float.parseFloat(tokenizer.nextToken());
			}

			ligne = br.readLine();
			tokenizer = new StringTokenizer(ligne);
			for (int i = 0; i < nbBlock; i++) {
				arrayModels[c][1][i] = Float.parseFloat(tokenizer.nextToken());
			}
		}
		br.close();
		return arrayModels;
	}

	static int[] resolveWar(float[][] blocks) {
		List<Float> nBlocks = new ArrayList<Float>();
		List<Float> kBlocks = new ArrayList<Float>();
		for (int i = 0; i < blocks[0].length; i++) {
			nBlocks.add(blocks[0][i]);
			kBlocks.add(blocks[1][i]);
		}
		Collections.sort(nBlocks);
		Collections.sort(kBlocks);

		int decWarScore = playDecWar(nBlocks, kBlocks);
		int warScore = playWar(nBlocks, kBlocks);
		System.out.println(decWarScore + " " + warScore);
		return new int[] { decWarScore, warScore };
	}

	static int playWar(List<Float> nBlocks, List<Float> kBlocks) {
		if (nBlocks.isEmpty()) {
			return 0;
		}
		int scoreMax = 0;
		for (int i = 0; i < nBlocks.size(); i++) {
			float nBlock = nBlocks.get(i);
			int indexOfFirstUpper = indexOfFirstUpper(kBlocks, nBlock);
			List<Float> nBlocksClone = new ArrayList<Float>(nBlocks);
			nBlocksClone.remove(i);
			List<Float> kBlocksClone = new ArrayList<Float>(kBlocks);
			int points = 0;
			if (indexOfFirstUpper == -1) {
				kBlocksClone.remove(0);
				points = 1 + playWar(nBlocksClone, kBlocksClone);
			} else {
				kBlocksClone.remove(indexOfFirstUpper);
				points = playWar(nBlocksClone, kBlocksClone);
			}
			if (points > scoreMax) {
				scoreMax = points;
			}
		}
		return scoreMax;
	}

	static void writeOutput(int[][] awnsers, String path) throws IOException {
		OutputStream ops = new FileOutputStream(path);
		OutputStreamWriter opsr = new OutputStreamWriter(ops);
		BufferedWriter bw = new BufferedWriter(opsr);

		for (int c = 0; c < awnsers.length; c++) {
			bw.write("Case #" + (c + 1) + ": " + awnsers[c][0] + " " + awnsers[c][1] + "\n");
		}
		bw.close();
	}

	static int playDecWar(List<Float> nBlocks, List<Float> kBlocks) {
		if (nBlocks.isEmpty()) {
			return 0;
		}
		int scoreMax = 0;

		float kBlock = kBlocks.get(0);// always the smallest
		int indexOfFirstUpperN = indexOfFirstUpper(nBlocks, kBlock);
		if (indexOfFirstUpperN >= 0) {
			List<Float> nBlocksClone = new ArrayList<Float>(nBlocks);
			nBlocksClone.remove(indexOfFirstUpperN);
			List<Float> kBlocksClone = new ArrayList<Float>(kBlocks);
			kBlocksClone.remove(0);
			return 1 + playDecWar(nBlocksClone, kBlocksClone);
		}
		for (int i = 0; i < nBlocks.size(); i++) {
			float nBlock = nBlocks.get(i);
			int indexOfFirstUpper = indexOfFirstUpper(kBlocks, nBlock);
			List<Float> nBlocksClone = new ArrayList<Float>(nBlocks);
			nBlocksClone.remove(i);
			List<Float> kBlocksClone = new ArrayList<Float>(kBlocks);
			int points = 0;
			if (indexOfFirstUpper == -1) {
				kBlocksClone.remove(0);
				points = 1 + playDecWar(nBlocksClone, kBlocksClone);
			} else {
				kBlocksClone.remove(indexOfFirstUpper);
				points = playDecWar(nBlocksClone, kBlocksClone);
			}
			if (points > scoreMax) {
				scoreMax = points;
			}
		}
		return scoreMax;
	}

	/**
	 * 
	 * @param kBlocks
	 *            must be sorted ascen
	 * @param upper
	 * @return
	 */
	static int indexOfFirstUpper(List<Float> kBlocks, float upper) {
		for (int i = 0; i < kBlocks.size(); i++) {
			if (kBlocks.get(i) > upper) {
				return i;
			}
		}
		return -1;
	}

	public static void main(String[] args) throws IOException {
		String inputPath = "inputs/D-small-attempt0.in";
		String outputPath = "outputs/D-small-attempt0.ou";
		float[][][] models = readInputs(inputPath);
		int[][] results = new int[models.length][];
		for (int i = 0; i < models.length; i++) {
			results[i] = resolveWar(models[i]);
		}
		writeOutput(results, outputPath);
		
	}
	

}
