import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.LinkedList;
import java.util.TreeMap;
import java.util.TreeSet;


class CharacterPair implements Comparable<CharacterPair> {
	final char ch1;
	final char ch2;
	
	public CharacterPair(char ch1, char ch2) {
		if (ch1 > ch2) {
			this.ch1 = ch1;
			this.ch2 = ch2;
		} else {
			this.ch1 = ch2;
			this.ch2 = ch1;
		}
	}

	@Override
	public int compareTo(CharacterPair arg0) {
		int ret = this.ch1 - arg0.ch1;
		if (ret == 0) {
			ret = this.ch2 - arg0.ch2;
		}
		return ret;
	}
}

public class Magicka {
	
	private static String parseCaseStr(String inputStr,
			TreeMap<CharacterPair, Character> combinePairs, 
			TreeMap<Character, Character> oppositePairs) {
		
		final String[] input = inputStr.split(" ");
		int currentIndex = 0;
		final int combineCount = Integer.parseInt(input[currentIndex++]);
		
		for (int i = 0; i < combineCount; ++ i) {
			String combineStr = input[currentIndex++];
			combinePairs.put(new CharacterPair(combineStr.charAt(0), combineStr.charAt(1)), combineStr.charAt(2));
		}
		
		final int oppositeCount = Integer.parseInt(input[currentIndex++]);
		
		for (int i = 0; i < oppositeCount; ++ i) {
			String oppositeStr = input[currentIndex++];
			oppositePairs.put(oppositeStr.charAt(0), oppositeStr.charAt(1));
			oppositePairs.put(oppositeStr.charAt(1), oppositeStr.charAt(0));
		}
		
		return input[currentIndex + 1];
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		
		try {
			String inFileName = args[0];
			BufferedReader in = new BufferedReader(new FileReader(inFileName));
			BufferedWriter out = new BufferedWriter(new FileWriter(inFileName + ".out"));
			int testCases = Integer.parseInt(in.readLine());
			
			for (int caseNo = 1; caseNo <= testCases; ++caseNo) {
			
				TreeMap<CharacterPair, Character> combinePairs = new TreeMap<CharacterPair, Character>();
				TreeMap<Character, Character> oppositePairs = new TreeMap<Character, Character>();
				final String caseStr = in.readLine();
				final String inputStr = parseCaseStr(caseStr, combinePairs, oppositePairs);				
				final LinkedList<Character> outSequence = new LinkedList<Character>();
				TreeSet<Character> oppositeChars = new TreeSet<Character>();
				
				for (int i = 0; i < inputStr.length(); ++i) {
					char ch = inputStr.charAt(i);
					
					if (outSequence.size() > 0) {
						char lastChar = outSequence.getLast();
						Character combinedChar = combinePairs.get(new CharacterPair(ch, lastChar));
						if (combinedChar != null) {
							outSequence.removeLast();
							outSequence.add(combinedChar);
							
							Character oppositeChar = oppositePairs.get(lastChar);
							
							if (oppositeChar != null && !outSequence.contains(lastChar)) {
								oppositeChars.remove(oppositeChar);
							}
							
							continue;
						}
					}
						
					if (oppositeChars.contains(ch)) {
						outSequence.clear();
						oppositeChars.clear();
						continue;
					}
						
					outSequence.add(ch);
					Character oppositeChar = oppositePairs.get(ch);
						
					if (oppositeChar != null) {
						oppositeChars.add(oppositeChar);
					}
				}
				
				StringBuilder s = new StringBuilder();
				
				for (Character ch : outSequence) {
					if (s.length() > 0) {
						s.append(", ");
					}
					s.append(ch);
				}
				
				String caseResultStr = "Case #" + caseNo + ": [" + s.toString() + "]\n";
				System.out.print(caseResultStr);
				out.write(caseResultStr);
				out.flush();
			}
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}
}
