/**
 * @author Maxim Degtyarev <mdegtyarev@gmail.com>
 */
import java.io.*;
import java.util.*;

public class ProblemD {

    private final Scanner input;
    private final PrintStream output;

    private String solveCase() {

		final int MULTIPLIER = 1000000;

		int trueResult;
		int deceitfulResult;

		int blockCount = input.nextInt();
		List<Integer> ourWeights = new ArrayList<Integer>(blockCount);
		List<Integer> enemyWeights = new ArrayList<Integer>(blockCount);

		for(int i = 0; i < blockCount; i++) {
			float floatValue = input.nextFloat();
			ourWeights.add((int)(floatValue * MULTIPLIER));
		}
		Collections.sort(ourWeights);

		for(int i = 0; i < blockCount; i++) {
			float floatValue = input.nextFloat();
			enemyWeights.add((int)(floatValue * MULTIPLIER));
		}
		Collections.sort(enemyWeights);

		trueResult = calculateTrueResult(new LinkedList<Integer>(ourWeights), new LinkedList<Integer>(enemyWeights));
		deceitfulResult = calculateDeceitfulResult(new LinkedList<Integer>(ourWeights), new LinkedList<Integer>(enemyWeights));

		assert (deceitfulResult >= trueResult): String.format("true: %d; deceitful: %d", trueResult, deceitfulResult);

		return deceitfulResult + " " + trueResult;
    }

	private int calculateDeceitfulResult(List<Integer> ourWeights, List<Integer> enemyWeights) {

		int result = 0;
		while ((!ourWeights.isEmpty())&&(true)) {
			if (ourWeights.get(ourWeights.size() - 1) < enemyWeights.get(enemyWeights.size() - 1)) {
				ourWeights.remove(0);
				enemyWeights.remove(enemyWeights.size() - 1);
			} else {
				ourWeights.remove(ourWeights.size() - 1);
				enemyWeights.remove(enemyWeights.size() - 1);
				result++;
			}
		}

		return result;
	}

	private int calculateTrueResult(List<Integer> ourWeights, List<Integer> enemyWeights) {

		int result = 0;

		nextStep: while (!ourWeights.isEmpty()) {
			int value = ourWeights.remove(0);

			for(int i = 0; i < enemyWeights.size(); i++) {
				if (enemyWeights.get(i) > value) {
					enemyWeights.remove(i);
					continue nextStep;
				}
			}
			enemyWeights.remove(0);
			result++;
		}

		return result;
	}

	private void invoke() {
        int caseCount = input.nextInt();

        String rest = input.nextLine();

        assert rest.length() == 0 : rest;

        String result;
        for(int caseNumber = 1; caseNumber <= caseCount; caseNumber++) {
            result = solveCase();
            output.printf("Case #%d: %s\n", caseNumber, result);
        }        
    }
    
    private ProblemD(InputStream input, PrintStream output) {
        this.input = new Scanner(input);
		this.input.useLocale(Locale.ROOT);
        this.output = output;
    }     
    
    public static void main(String... args) throws FileNotFoundException {

        InputStream inputStream;
        PrintStream outputStream;
        
        if (args.length > 0) {
            
            final String inputFileName = args[0];
            final String outputFileName;
            
            if (inputFileName.endsWith(".in")) {
                outputFileName = inputFileName.substring(0, inputFileName.length() - 3) + ".out";
            } else {
                outputFileName = inputFileName + ".out";
            }

            inputStream = new FileInputStream(inputFileName);
            outputStream = new PrintStream(outputFileName);

        } else {
            inputStream = System.in;
            outputStream = System.out;
        }
        
        ProblemD instance = new ProblemD(inputStream, outputStream);
        
        instance.invoke();        
    }

}
