import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Locale;
import java.util.TreeSet;


class MatchResult {
	final int opponentTeam;
	final double winResult;
	
	MatchResult(int opponentTeam, double winResult) {
		this.opponentTeam = opponentTeam;
		this.winResult = winResult;
	}
}

class Team {
	double wp = 0;
	double owp = 0;
	double oowp = 0;
	final LinkedList<MatchResult> matches = new LinkedList<MatchResult>();
	
	double getRpi() {
		return 0.25 * wp + 0.50 * owp + 0.25 * oowp;
	}
	
	void calculateWp() {
		wp = calculateWp(-1);
	}
	
	double calculateWp(int excludeOpponent) {
		double wins = 0;
		int count = 0;
		
		for (MatchResult r : matches) {
			if (r.opponentTeam == excludeOpponent) {
				continue;
			}
			
			wins += r.winResult;
			++count;
		}
		
		return wins / count;
	}
}

public class FreeCellStatistics {

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		
		String inFileName = args[0];
		BufferedReader in = new BufferedReader(new FileReader(inFileName));
		BufferedWriter out = new BufferedWriter(new FileWriter(inFileName + ".out"));
		int testCases = Integer.parseInt(in.readLine());

		for (int caseNo = 1; caseNo <= testCases; ++caseNo) {
			final int N = Integer.parseInt(in.readLine());
			final Team[] teams = new Team[N];
			
			for (int i = 0; i < N; ++i) {
				String matches = in.readLine();
				final Team t = new Team();
				teams[i] = t;
				for (int op = 0; op < N; ++op) {
					char ch = matches.charAt(op);
					if (ch == '.') {
						continue;
					}
					final double win = ch == '1' ? 1.0 : 0;
					t.matches.add(new MatchResult(op, win));
				}
				
				t.calculateWp();
			}
			
			for (int i = 0; i < N; ++i) {
				Team t = teams[i];
				double wins = 0;
				for (MatchResult r : t.matches) {
					wins += teams[r.opponentTeam].calculateWp(i);
				}
				
				t.owp = wins / t.matches.size();
			}
			
			for (int i = 0; i < N; ++i) {
				Team t = teams[i];
				double wins = 0;
				for (MatchResult r : t.matches) {
					wins += teams[r.opponentTeam].owp;
				}
				
				t.oowp = wins / t.matches.size();
			}
			
			StringBuilder result = new StringBuilder();
			
			for (int i = 0; i < N; ++i) {
				Team t = teams[i];
				result.append(String.format(Locale.US, "%.12f", t.getRpi()) + "\n");
			}
			
			final String resultStr = "Case #" + caseNo + ":\n" + result.toString(); 
			out.write(resultStr);
			System.out.print(resultStr);
			out.flush();
		}
	}
}
