import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.Locale;


class Tile {
	final char ch;
	
	Tile(char ch) {
		this.ch = ch;
	}
	
	boolean isBlue() {
		return ch == '#';
	}
	
	boolean isWhite() {
		return ch == '.'; 
	}
	
	boolean isRed() {
		return ch == '/' || ch == '\\'; 
	}
}

public class FreeCellStatistics {

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		
		String inFileName = args[0];
		BufferedReader in = new BufferedReader(new FileReader(inFileName));
		BufferedWriter out = new BufferedWriter(new FileWriter(inFileName + ".out"));
		int testCases = Integer.parseInt(in.readLine());

		for (int caseNo = 1; caseNo <= testCases; ++caseNo) {
			final String[] RC = in.readLine().split(" ");
			final int rowCount = Integer.parseInt(RC[0]);
			final int columnCount = Integer.parseInt(RC[1]);
			final Tile[][] xy = new Tile[columnCount][rowCount];
			
			for (int y = 0; y < rowCount; ++y) {
				String row = in.readLine();
				for (int x = 0; x < columnCount; ++x) {
					xy[x][y] = new Tile(row.charAt(x));
				}
			}
			
			boolean possible = true;
			
			for (int y = 0; y < rowCount && possible; ++y) {
				for (int x = 0; x < columnCount; ++x) {
					Tile t = xy[x][y];
					
					if (!t.isBlue()) {
						continue;
					}
					
					if (y < rowCount - 1 && x < columnCount - 1 &&
						xy[x + 1][y].isBlue() &&
						xy[x + 1][y + 1].isBlue() &&
						xy[x][y + 1].isBlue()) {
						xy[x][y] = new Tile('/');
						xy[x + 1][y + 1] = new Tile('/');
						xy[x + 1][y] = new Tile('\\');
						xy[x][y + 1] = new Tile('\\');
					} else {
						possible = false;
						break;
					}
				}
			}
			
			StringBuilder result = new StringBuilder();
			
			if (!possible) {
				result.append("Impossible\n");
			} else {
				for (int y = 0; y < rowCount && possible; ++y) {
					for (int x = 0; x < columnCount; ++x) {
						result.append(xy[x][y].ch);
					}
					result.append('\n');
				}
			}
			
			final String resultStr = "Case #" + caseNo + ":\n" + result.toString();
			out.write(resultStr);
			System.out.print(resultStr);
			out.flush();
		}
	}
}
