package mp.kotter.challenges.gcj.qualification;

import java.io.IOException;
import java.util.List;

import mp.kotter.challenges.utils.Solution;

public class Lawnmower extends Solution {

    public static void main(final String[] args) throws Exception {
        (new Lawnmower()).run(args);
    }

    @Override
    protected void solve() throws Exception {
        final int T = Integer.parseInt(getInput().readLine());

        for(int c=0; c<T; c++) {
            writeCaseResult(c, solveCase());
        }
    }

    private String solveCase() throws IOException {
        final int[][] pattern = readInputData();
        final int[][] mask = maskFromPattern(pattern);

        final int h = pattern.length;
        final int w = pattern[0].length;

        for(int i=0; i<h; i++) {
            updateMask(mask, pattern, i, 0, 0, 1, w);
        }

        for(int i=0; i<w; i++) {
            updateMask(mask, pattern, 0, i, 1, 0, h);
        }

        return patternsEquals(pattern, mask) ? "YES" : "NO";
    }

    private boolean patternsEquals(final int[][] pattern, final int[][] mask) {
        if (pattern.length != mask.length) {
            return false;
        }

        for(int i=0; i<pattern.length; i++) {
            if (pattern[i].length != mask[i].length) {
                return false;
            }

            for(int j=0; j<pattern[i].length; j++) {
                if (pattern[i][j] != mask[i][j]) {
                    return false;
                }
            }
        }

        return true;
    }

    private void updateMask(
            final int[][] mask,
            final int[][] pattern,
            int r, int c,
            final int dr, final int dc,
            final int l) {
        int max = 0;

        for(int i=0; i<l; i++) {
            if (max < pattern[r][c]) {
                max = pattern[r][c];
            }

            r += dr;
            c += dc;
        }

        for(int i=0; i<l; i++) {
            r -= dr;
            c -= dc;

            if (mask[r][c] > max) {
                mask[r][c] = max;
            }
        }
    }

    private int[][] maskFromPattern(final int[][] pattern) {
        final int[][] result = new int[pattern.length][];

        for(int i=0; i<result.length; i++) {
            result[i] = new int[pattern[i].length];
            for(int j=0; j<result[i].length; j++) {
                result[i][j] = 100;
            }
        }

        return result;
    }

    private int[][] readInputData() throws IOException {
        final List<Integer> sizes = readInts();
        final int h = sizes.get(0);
        final int w = sizes.get(1);

        final int[][] result = new int[h][];

        for(int i=0; i<h; i++) {
            result[i] = new int[w];
            final List<Integer> row = readInts();
            for(int j=0; j<w; j++) {
                result[i][j] = row.get(j);
            }
        }

        return result;
    }
}
