package farm;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.text.DecimalFormat;
import java.util.StringTokenizer;

public class FramSolver {
	static class FarmModel {
		double C_farm_cost;
		double F_farm_increment;
		double X_cookies_wanted;
	}

	static FarmModel[] readInputs(String path) throws IOException {
		InputStream ips = new FileInputStream(path);
		InputStreamReader ipsr = new InputStreamReader(ips);
		BufferedReader br = new BufferedReader(ipsr);
		String ligne;

		ligne = br.readLine();
		int casesCount = Integer.parseInt(ligne);
		FarmModel[] arrayModels = new FarmModel[casesCount];

		for (int c = 0; c < casesCount; c++) {
			arrayModels[c] = new FarmModel();
			ligne = br.readLine();
			StringTokenizer tokenizer = new StringTokenizer(ligne);
			arrayModels[c].C_farm_cost = Double.parseDouble(tokenizer.nextToken());
			arrayModels[c].F_farm_increment = Double.parseDouble(tokenizer.nextToken());
			arrayModels[c].X_cookies_wanted = Double.parseDouble(tokenizer.nextToken());
		}

		br.close();
		return arrayModels;
	}

	static double resolveFarm(FarmModel model) {
		double elapsedTime = 0.0d;
		double cookieRatePerSecond = 2.0d;
		boolean keep = true;
		while (keep) {
			double remainTimeToGoal = model.X_cookies_wanted / cookieRatePerSecond;
			double remainTimeToFarm = model.C_farm_cost / cookieRatePerSecond;
			double remainTimeToGoalWithOneMoreFarm = remainTimeToFarm + model.X_cookies_wanted / (cookieRatePerSecond + model.F_farm_increment);
			if (remainTimeToGoal <= remainTimeToGoalWithOneMoreFarm) {
				elapsedTime += remainTimeToGoal;
				keep = false;
			} else {
				elapsedTime += remainTimeToFarm;
				cookieRatePerSecond += model.F_farm_increment;
			}
		}

		return elapsedTime;
	}

	static void writeOutput(double[] awnsers, String path) throws IOException {
		OutputStream ops = new FileOutputStream(path);
		OutputStreamWriter opsr = new OutputStreamWriter(ops);
		BufferedWriter bw = new BufferedWriter(opsr);

		DecimalFormat f = new DecimalFormat();
		f.setMinimumFractionDigits(7);
		f.setMaximumFractionDigits(7);
		
		for (int c = 0; c < awnsers.length; c++) {
			bw.write("Case #" + (c + 1) + ": " + f.format(awnsers[c]).replace(',', '.') + "\n");
		}
		bw.close();
	}

	public static void main(String[] args) throws IOException {
		String inputPath = "inputs/B-small-attempt3.in";
		String outputPath = "outputs/B-small-attempt3.ou";
		FarmModel[] models = readInputs(inputPath);
		double[] awnsers = new double[models.length];
		for (int i = 0; i < models.length; i++) {
			awnsers[i] = resolveFarm(models[i]);
		}
		writeOutput(awnsers, outputPath);

	}
}
