import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.Locale;


class Interval {
	
	static double D = 1;
	
	double begin = 0;
	double end = 0;
	double maxVendor = 0;
	double minVendor = 0;
	
	private Interval(){
		
	}
	
	Interval(int vendorsCount, double vendorPosition) {
		this.maxVendor = vendorPosition;
		this.minVendor = vendorPosition;
		double interval = vendorsCount * D;
		this.begin = vendorPosition - interval / 2;
		this.end = vendorPosition + interval / 2;
	}
	
	double width() {
		return this.end - this.begin;
	}
	
	double vendorWidth() {
		return this.maxVendor - this.minVendor;
	}
	
	Interval merge(Interval other) {
		Interval newInterval = new Interval();
		newInterval.maxVendor = Math.max(this.maxVendor, other.maxVendor);
		newInterval.minVendor = Math.min(this.minVendor, other.minVendor);
		final double interval = this.width() + other.width();
		final double vendorInterval = newInterval.vendorWidth();
		final double indent = (interval - vendorInterval) / 2;
		newInterval.end = newInterval.maxVendor + indent;
		newInterval.begin = newInterval.minVendor - indent;
		
		return newInterval;
	}
	
	boolean intercepts(Interval other) {
		return Math.max(this.end, other.end) - Math.min(this.begin, other.begin) < this.width() + other.width();
	}
	
	double spreadTime() {
		return  Math.max(end - D / 2 - maxVendor, 0);
	}
}

public class FreeCellStatistics {

	/**
	 * @param args
	 * @throws IOException 
	 */
	public static void main(String[] args) throws IOException {
		
		String inFileName = args[0];
		BufferedReader in = new BufferedReader(new FileReader(inFileName));
		BufferedWriter out = new BufferedWriter(new FileWriter(inFileName + ".out"));
		int testCases = Integer.parseInt(in.readLine());

		for (int caseNo = 1; caseNo <= testCases; ++caseNo) {
			String[] CD = in.readLine().split(" ");
			final int pointCount = Integer.parseInt(CD[0]);
			Interval.D = Integer.parseInt(CD[1]);
			LinkedList<Interval> intervals = new LinkedList<Interval>();
			
			for (int i = 0; i < pointCount; ++i) {
				String[] PV = in.readLine().split(" ");
				double point = Integer.parseInt(PV[0]);
				int vendorCount = Integer.parseInt(PV[1]);
				intervals.add(new Interval(vendorCount, point));
			}
			
			Collections.sort(intervals, new Comparator<Interval>() {
				@Override
				public int compare(Interval o1, Interval o2) {
					return (int)Math.signum(o1.minVendor - o2.minVendor);
				}
			});
			
			LinkedList<Interval> processedIntervals = new LinkedList<Interval>();
			
			while (!intervals.isEmpty()) {
				Interval i = intervals.pop();
				
				if (processedIntervals.isEmpty()) {
					processedIntervals.push(i);
					continue;
				}
				
				Interval prev = processedIntervals.peek();
				
				if (prev.intercepts(i)) {
					processedIntervals.pop();
					intervals.push(prev.merge(i));
				} else {
					processedIntervals.push(i);
				}
			}
			
			double time = processedIntervals.element().spreadTime();
			
			for (Interval i : processedIntervals) {
				time = Math.max(time, i.spreadTime());
			}
			
			StringBuilder result = new StringBuilder();
			result.append(String.format(Locale.US, "%f", time));
			
			final String resultStr = "Case #" + caseNo + ": " + result.toString() + "\n";
			out.write(resultStr);
			System.out.print(resultStr);
			out.flush();
		}
	}
}
