import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.StringTokenizer;

public class Rotate {
	private String processGrid(int[][] grid, int K) {
		applyGravity(grid);
		
		boolean foundRed = false, foundBlue = false;
		for (int i = 0; i < grid.length; i++) {
			for (int j = 0; j < grid[0].length; j++) {
				if (grid[i][j] == 1 && !foundRed) {
					foundRed = search(grid, i, j, K);
				} else if (grid[i][j] == 2 && !foundBlue) {
					foundBlue = search(grid, i, j, K);
				}
				
				if (foundRed && foundBlue) {
					break;
				}
			}
		}
		
		if (foundRed && foundBlue) {
			return "Both";
		} else if (foundRed) {
			return "Red";
		} else if (foundBlue) {
			return "Blue";
		} else {
			return "Neither";
		}
	}
	
	private boolean search(int[][] grid, int row, int col, int K) {
		int value = grid[row][col];
		
		boolean vertical = true, horizontal = true, diagonal1 = true, diagonal2 = true;
		for (int i = 1; i < K; i++) {
			if (row + i >= grid.length || grid[row + i][col] != value) {
				vertical = false;
			}
			if (col + i >= grid[0].length || grid[row][col + i] != value) {
				horizontal = false;
			}
			if (row + i >= grid.length || col + i >= grid[0].length || grid[row + i][col + i] != value) {
				diagonal1 = false;
			}
			if (row + i >= grid.length || col - i < 0 || grid[row + i][col - i] != value) {
				diagonal2 = false;
			}
		}
		
		return vertical || horizontal || diagonal1 || diagonal2;
	}
	
	private void applyGravity(int [][] grid) {
		int endIndex;
		for (int i = 0; i < grid.length; i++) {
			endIndex = grid[0].length - 1;
			for (int j = endIndex; j >= 0; j--) {
				if (grid[i][j] != 0) {
					if (j != endIndex) {
						grid[i][endIndex--] = grid[i][j];
						grid[i][j] = 0;
					} else {
						endIndex--;
					}
				}
			}
		}
	}

	public void process(String inputFile, String outputFile) {
		try {
			FileWriter writer = new FileWriter(new File(outputFile));
			BufferedReader fileIn = new BufferedReader(new FileReader(inputFile));

			int numCases = Integer.parseInt(fileIn.readLine());
			for (int i = 0; i < numCases; i++) {
				String descriptor = fileIn.readLine();
				StringTokenizer st = new StringTokenizer(descriptor, " ");
				
				int N = Integer.parseInt(st.nextToken());
				int K = Integer.parseInt(st.nextToken());
				
				int[][] grid = new int[N][N];
				for (int j = 0; j < N; j++) {
					String row = fileIn.readLine();
					for (int k = 0; k < N; k++) {
						if (row.charAt(k) == '.') {
							grid[j][k] = 0;
						} else {
							grid[j][k] = row.charAt(k) == 'R' ? 1 : 2;
						}
					}
				}
				writer.write("Case #" + (i + 1) + ": " + processGrid(grid, K) + "\n");
			}
			writer.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
