import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.TreeSet;

public class D {

    private static TreeSet<Double> parseBlocks(String[] input) {
        TreeSet<Double> blockTree = new TreeSet<>();

        for (String block : input) {
            blockTree.add(Double.valueOf(block));
        }

        return blockTree;
    }
    
       
    
    private static int getWarWins(TreeSet<Double> naomisBlockTree, TreeSet<Double> kensBlockTree) {
        int numWinsWar = 0;

        // War
        for (Double naomisBlockValue : naomisBlockTree) {
            Double kensChoice;
            if ((kensChoice = kensBlockTree.ceiling(naomisBlockValue)) != null) {
                // Ken wins
                kensBlockTree.remove(kensChoice);
            } else {
                // Naomi wins and ken plays lowest possible piece
                numWinsWar++;
                kensBlockTree.remove(kensBlockTree.first());
            }
        }

        return numWinsWar;
    }
    
    private static int getDeceitfulWarWins(int numBlocks,
            TreeSet<Double> naomisBlockTree, TreeSet<Double> kensBlockTree) {
        int numWinsDeceitfulWar = 0;

        // Deceitful War
        for (int i = 0; i < numBlocks; i++) {
            if (naomisBlockTree.last() > kensBlockTree.last()) {
                // Tell Ken value higher than his highest, actually use ceiling of his lowest
                numWinsDeceitfulWar++;
                naomisBlockTree.remove(naomisBlockTree.ceiling(kensBlockTree.first()));
                kensBlockTree.remove(kensBlockTree.first());
            } else {
                // Tell Ken weight 0.00001 below his highest
                naomisBlockTree.remove(naomisBlockTree.first());
                kensBlockTree.remove(kensBlockTree.last());
            }
        }

        return numWinsDeceitfulWar;
    }

    private static String processCaseInput(BufferedReader br)
            throws IOException {
        String line = br.readLine();
        int numBlocks = Integer.valueOf(line);

        line = br.readLine();
        String[] naomisBlocksInput = line.split(" ");
        TreeSet<Double> naomisBlockTree = parseBlocks(naomisBlocksInput);
        TreeSet<Double> naomisDeceitfulBlockTree = parseBlocks(naomisBlocksInput);

        line = br.readLine();
        String[] kensBlocksInput = line.split(" ");
        TreeSet<Double> kensBlockTree = parseBlocks(kensBlocksInput);
        TreeSet<Double> kensDeceitfulBlockTree = parseBlocks(kensBlocksInput);

        int warWins = getWarWins(naomisBlockTree, kensBlockTree);
        int deceitfulWarWins = getDeceitfulWarWins(numBlocks, naomisDeceitfulBlockTree, kensDeceitfulBlockTree);
        
        return String.format("%d %d", deceitfulWarWins, warWins);
    }

    public static void main(String[] args) {
        int numCases = 0;

        if (args.length != 1) {
            System.err.println("Input file required for processing");
            System.exit(0);
        }

        // Create the output file
        File outputFile = new File("output.out");
        if (!outputFile.exists()) {
            try {
                outputFile.createNewFile();
            } catch (IOException e) {
                e.printStackTrace();
                System.exit(0);
            }
        }

        // Read input
        try (FileWriter fw = new FileWriter(outputFile.getAbsoluteFile());
                BufferedWriter bw = new BufferedWriter(fw);
                BufferedReader br = new BufferedReader(new FileReader(args[0]));) {

            // First line should contain the number of test cases
            String line = br.readLine();
            numCases = Integer.parseInt(line);

            long startTime = System.currentTimeMillis();

            // Following lines should contain test cases
            for (int i = 1; i <= numCases && line != null; i++) {
                String caseAnswer = processCaseInput(br);
                String outputLine = "Case #" + i + ": " + caseAnswer;
                System.out.println(outputLine);
                bw.write(outputLine + "\n");
            }

            long endTime = System.currentTimeMillis();
            System.out.println("Execution time = " + (endTime - startTime));
        } catch (IOException e) {
            System.out.println("Input file not found!");
            e.printStackTrace();
        }
    }
}