import java.io.*;
import java.util.*;

public class ProblemA {

    private final Scanner input;
    private final PrintStream output;
    private static final Map<Character, Character> translationMap;


    private String solveCase() {
        StringBuilder result = new StringBuilder();

        String line = input.nextLine();

        for(int index = 0; index < line.length(); index++) {
            char ch = line.charAt(index);

            result.append(translationMap.get(ch));
        }

        return result.toString();
    }

    private void invoke() {
        int caseCount = input.nextInt();

        String rest = input.nextLine();

        assert rest.length() == 0 : rest;

        String result;
        for(int caseNumber = 1; caseNumber <= caseCount; caseNumber++) {
            result = solveCase();
            output.printf("Case #%d: %s\n", caseNumber, result);
        }        
    }
    
    private ProblemA(InputStream input, PrintStream output) {
        this.input = new Scanner(input);
        this.output = output;
    }     
    
    public static void main(String... args) throws FileNotFoundException {

        InputStream inputStream;
        PrintStream outputStream;
        
        if (args.length > 0) {
            
            final String inputFileName = args[0];
            final String outputFileName;
            
            if (inputFileName.endsWith(".in")) {
                outputFileName = inputFileName.substring(0, inputFileName.length() - 3) + ".out";
            } else {
                outputFileName = inputFileName + ".out";
            }

            inputStream = new FileInputStream(inputFileName);
            outputStream = new PrintStream(outputFileName);

        } else {
            inputStream = System.in;
            outputStream = System.out;
        }
        
        ProblemA instance = new ProblemA(inputStream, outputStream);
        
        instance.invoke();        
    }

    static {

        translationMap = new HashMap<Character, Character>();

        // Space remain unchanged
        translationMap.put(' ', ' ');
        //  'a' -> 'y', 'o' -> 'e', and 'z' -> 'q'. This means that "a zoo" will become "y qee".
        //translationMap.put('e', 'o');
        //translationMap.put('y', 'a');
        //translationMap.put('q', 'z');

        translationMap.put('a', 'y');
        translationMap.put('b', 'h');
        translationMap.put('c', 'e');
        translationMap.put('d', 's');
        translationMap.put('e', 'o');
        translationMap.put('f', 'c');
        translationMap.put('g', 'v');
        translationMap.put('h', 'x');
        translationMap.put('i', 'd');
        translationMap.put('j', 'u');
        translationMap.put('k', 'i');
        translationMap.put('l', 'g');
        translationMap.put('m', 'l');
        translationMap.put('n', 'b');
        translationMap.put('o', 'k');
        translationMap.put('p', 'r');
        translationMap.put('q', 'z');
        translationMap.put('r', 't');
        translationMap.put('s', 'n');
        translationMap.put('t', 'w');
        translationMap.put('u', 'j');
        translationMap.put('v', 'p');
        translationMap.put('w', 'f');
        translationMap.put('x', 'm');
        translationMap.put('y', 'a');
        translationMap.put('z', 'q');

    }
}
