import java.util.*;

public class Problem {
	public static void main(String... args) {
		Locale.setDefault(Locale.ENGLISH);
		for (DataSet dataSet : new DataSets())
			handleDataSet(dataSet);
	}


	private static void handleDataSet(DataSet dataSet) {
		System.out.println(
			"Case #" + dataSet.number + ": " + dataSet.getResult());
	}

	public static class DataSet {
		public long number;
		public List<Double> naomi, ken;
	

		public String getResult() {
			Collections.sort(naomi);
			Collections.sort(ken);
			return calculateDeceitfulWar() + " " + calculateWars();		
		}

		public int calculateWars() {
			List<Double> copyOfKen = new LinkedList<Double>(ken);
			for (double x : naomi) {
				Double y = findKen(copyOfKen, x);
				if (y != null)
					copyOfKen.remove(y);
			}
			return copyOfKen.size();
		}

		public Double findKen(List<Double> ken, double naomi) {
			for (double y : ken)
				if (y > naomi)
					return y;
			return null;
		}

		public int calculateDeceitfulWar() {
			LinkedList<Double> copyOfNaomi = new LinkedList<Double>(naomi);
			LinkedList<Double> copyOfKen = new LinkedList<Double>(ken);
			int score = 0;
			while (!copyOfNaomi.isEmpty()) {
				if (copyOfNaomi.getLast() > copyOfKen.getLast()) {
					++score;
					double kenValue = copyOfKen.pollFirst();
					Iterator<Double> it = copyOfNaomi.iterator();
					while (true) {
						if (it.next() > kenValue) {
							it.remove();
							break;
						}
					}
				} else {
					copyOfNaomi.pollFirst();
					copyOfKen.pollLast(); 
				}
			}
			return score;
		}
	}

	public static class DataSets implements Iterable<DataSet> {
		public Iterator<DataSet> iterator() {
			return new DataSetsIterator();
		}		
	}

	public static class DataSetsIterator implements Iterator<DataSet> {
		private final long numberOfDataSets;
		private final Scanner sc;
		private long indexOfCurrentDataSet; //zero based

		public DataSetsIterator() {
			sc = new Scanner(System.in);
			numberOfDataSets = sc.nextLong();
			nextLine();
			indexOfCurrentDataSet = 0;
		}

		public boolean hasNext() {
			return indexOfCurrentDataSet < numberOfDataSets;
		}

		public DataSet next() {
			DataSet dataSet = new DataSet();
			dataSet.number = ++indexOfCurrentDataSet;
			int numberOfWeights = sc.nextInt();
			nextLine();
			dataSet.naomi = readWeights(numberOfWeights);
			dataSet.ken = readWeights(numberOfWeights);
			return dataSet;
		}

		public List<Double> readWeights(int numberOfWeights) {
			List<Double> weights = new ArrayList<>();
			for (int i = 0; i < numberOfWeights; ++i)
				weights.add(sc.nextDouble());
			nextLine();
			return weights;
		}

		private void nextLine() {
			sc.nextLine();
		}

		public void remove() {
			throw new UnsupportedOperationException();
		}
	}
}
